// Module: PosWCS
//
// Author: Hassan Siddiqui
//
// Description: 
//
// Reads in X/Y WCS from a given dataset.
//
// If the info in invalid/not present, 
// the valid() method will return false.
//
// Modifications: See ChangeLog
// 
// $Id: PosWCS.h,v 1.2 2012/04/18 09:05:36 eojero Exp $

#ifndef PosWCS_H
#define PosWCS_H

#include <iostream>

/* SAS-specific */
#include "Dal.h"

/* Local classes */
#include "WCSConvertor.h"


class PosWCS
{
public:

  /* Read state from dataset */
  PosWCS( const DataSet * const set,
	  double default_ra,
	  double default_dec,
          double refpa,
          bool useodf );

  /* Destructor */
 ~ PosWCS();

  /* Returns a pointer to WCS object */
  const WCSConvertor * const wcs() const;

  /* Returns the default dec,ra,pa */
  const double refra() const;
  const double refdec() const;
  const double pa() const;

  /* Returns whether to use the ODF for attitude reconstruction */
  const bool useODF() const;

  /* std output contents of PosWCS */
  friend ostream & operator<< (ostream & os, const PosWCS & wcs);

private:

//  bool _valid;

  double _refra;
  double _refdec;
  double _refpa;

  bool _useodf;

  const WCSConvertor * _wcs;
};

#endif
