// 
// Module: PositionUtils
// Author: Hassan Siddiqui
//
// Description
// Provides utilites for coordinate conversions,
// source position
// and CCD number determination, based on a position.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: PositionUtils.h,v 1.1 2011/01/11 16:36:10 rsaxton Exp $

#ifndef PositionUtils_H
#define PositionUtils_H

/* General */

/* SAS-specific classes */
#include "Tracer.h"
#include "CalServer.h"

/* Local classes */
#include "SourcePosition.h"
#include "CamCoords.h"
#include "TelCoords.h"
#include "PixCoords.h"
#include "PosWCS.h"

class PositionUtils
{

public:

  /** Constructors  */
  PositionUtils( const  Xmm::Instrument & instrumentID);

  /**  Destructors  */
  ~PositionUtils();

  /* Convert from DETX/DETY (0.05 arcsec units) to camcoord2 */
  const CamCoords detxy005ToCamCoord2( double detx, 
				       double dety ) const;

  /* Convert from camcoord2 to DETX/DETY (0.05 arcsec units) */
  const double CamCoord2Todetxy005( double incamcoord ) const;
  const CoordPair CamCoord2Todetxy005( 
                           const CamCoords & camCoord2 ) const;

  /* Convert from RAW coords to DETX/DETY */
  const CoordPair RawTodetxy005( double rawx, double rawy, int ccdnr = -1 ) const;

  /* Convert between CAMCOORD2 and TELCOORD */
  const TelCoords camCoord2ToTelCoord( const CamCoords & camcoords ) const;
  const CamCoords TelCoordTocamCoord2( const TelCoords & telcoords ) const;

  /* Convert from CAMCOORD2 to PIXCOORD */
  const PixCoords camCoord2ToPixCoord( const CamCoords & camcoords ) const;

  /* Convert from PIXCOORD to CAMCOORD2 */
  const CamCoords PixCoordTocamCoord2( const PixCoords & pixCoords, int ccdnr = -1 ) const;

  /* Find the width in detector coordinates of a single raw pixel */
  const vector<double> detxyWidth( ) const;

  /* Set ccd state according to CamCoords input */
  bool setCcd(const CamCoords & camcoord);

  /* Compute Source position */
  const SourcePosition sourcePosition( const string & sourceCoordType,
				       const string & datamode,
				       const string & dateobs,
				       double sourcex,
				       double sourcey,
				       const PosWCS * const poswcs,
				       int ccdnr = -1);

  friend ostream & operator<< (ostream & os, const PositionUtils & pu);

private:

  /** Members */

  /* DET (0.05 arcsec) to CAMCOORD2 conversion */
  double _detToCamcoord2;
  double _cenDetX;
  double _cenDetY;
  
  unsigned _ccd_xmin;
  unsigned _ccd_xmax;
  unsigned _ccd_ymin;
  unsigned _ccd_ymax;
  unsigned _cent_ccd;
  unsigned _nccds;

  CCDwindow *_ccdwindow;

  /* The gap width, in raw pixels */
  static const unsigned _CCD_GAP = 1;
  
};
#endif
