proc psf_button {} {
	puts "create psf ..."
	global config lvl ctype executable
	
	set ind [.frm_levl.lst curselection]
	if {$ind != {}} {set config(level) [lindex $lvl $ind]}

	set ind [.frm_ctype.lst curselection]
	if {$ind != {}} {set config(coortype) [lindex $ctype $ind]}

	set command [list exec $executable]

	foreach para [array names config] {
		if { $para != "userccf" } {
			if { $para != "ccf" } {
				lappend command "$para=$config($para)"
			} else {
				if { $config(userccf) != "no" } { lappend command "ccf=$config(ccf)" }
			}
		}
	}

	lappend command "output=temp.fits"

	puts "Executing command \[[lrange $command 1 end]\] ... "

	if  { [catch {eval $command} result] } {
		puts "Command execution failed with message: $result"
	} else {
		exec xpaset -p ds9 file temp.fits
	}
}

proc ccf_button {} {
	global config

	set config(ccf) [tk_getOpenFile -initialdir '.' -initialfile $config(ccf)]
}

#Global Variables
array set config {
	instrument	"EMOS1"
	userccf		"no"
	ccf		"ccf.cif"
	level		"MEDIUM"
	coortype	"XY"
	energy		"3000.0"
	theta		"0.0"
	phi		"0.0"
	rotate		"0.0"
	xsize		"199"
	ysize		"199"
}
#	ccdtemp		"120"
#	camtemp		"120"
set lvl [list "LOW" "MEDIUM" "EXTENDED" "ELLBETA" "HIGH"]
set ctype [list "XY" "DET" "RAW"]
set executable "../../src/psfgen"

if {[file exists $executable] != 1 || [file executable $executable] != 1} {
	puts "Executable $executable does not exist"
	exit 1 
}

#instrument GUI
frame .frm_instr -relief solid
label .frm_instr.lbl -text "Instrument:"
radiobutton .frm_instr.emos1 -text "EMOS1" -variable config(instrument) -value "EMOS1"
radiobutton .frm_instr.emos2 -text "EMOS2" -variable config(instrument) -value "EMOS2"
radiobutton .frm_instr.epn -text "EPN" -variable config(instrument) -value "EPN"

#ccffile GUI
frame .frm_ccf -relief solid
label .frm_ccf.lbl -text "Use CCF File:"
radiobutton .frm_ccf.no -text "no" -variable config(userccf) -value "no"
radiobutton .frm_ccf.yes -text "yes" -variable config(userccf) -value "yes"
entry .frm_ccf.ent -width 20 -textvariable config(ccf)
button .frm_ccf.but -text "Browse" -command "ccf_button"

#tempreture GUI
#frame .frm_temp -relief solid
#label .frm_temp.lbl_ccd -text "CCD temp:"
#label .frm_temp.lbl_cam -text "Camera temp:"
#entry .frm_temp.ent_ccd -width 15 -textvariable config(ccdtemp)
#entry .frm_temp.ent_cam -width 15 -textvariable config(camtemp)

#level GUI
frame .frm_levl -relief solid
label .frm_levl.lbl -text "Level:"
listbox .frm_levl.lst -listvariable lvl -selectmode single -height 6

#coordinate type GUI
frame .frm_ctype -relief solid
label .frm_ctype.lbl -text "Coordinate:"
listbox .frm_ctype.lst -listvariable ctype -selectmode single -height 4

#energy GUI
frame .frm_eng -relief solid
label .frm_eng.lbl -text "Energy (eV):"
entry .frm_eng.ent -width 15 -textvariable config(energy)

#position GUI
frame .frm_pos -relief solid
label .frm_pos.lbl_theta -text "Theta (arcsec):"
label .frm_pos.lbl_phi -text "Phi (deg):"
label .frm_pos.lbl_rotate -text "Roate (deg):"
entry .frm_pos.ent_theta -width 15 -textvariable config(theta)
entry .frm_pos.ent_phi -width 15 -textvariable config(phi)
entry .frm_pos.ent_rotate -width 15 -textvariable config(rotate)

#size GUI
frame .frm_size -relief solid
label .frm_size.lbl_x -text "xsize (pixel):"
label .frm_size.lbl_y -text "ysize (pixel):"
entry .frm_size.ent_x -width 15 -textvariable config(xsize)
entry .frm_size.ent_y -width 15 -textvariable config(ysize)

#button GUI
frame .frm_but -relief solid
button .frm_but.psf -text "PSF" -command "psf_button"
button .frm_but.quit -text "Success" -command "exit 0"
button .frm_but.abort -text "Failure" -command "exit 1"

#geometry management
grid .frm_instr.lbl -in .frm_instr -row 1 -column 1 -columnspan 5
grid .frm_instr.emos1 -in .frm_instr -row 2 -column 2
grid .frm_instr.emos2 -in .frm_instr -row 2 -column 3
grid .frm_instr.epn -in .frm_instr -row 2 -column 4

grid .frm_ccf.lbl -in .frm_ccf -row 1 -column 1
grid .frm_ccf.no -in .frm_ccf -row 1 -column 2
grid .frm_ccf.yes -in .frm_ccf -row 1 -column 3
grid .frm_ccf.ent -in .frm_ccf -row 2 -column 1 -columnspan 2
grid .frm_ccf.but -in .frm_ccf -row 2 -column 3

#grid .frm_temp.lbl_ccd -in .frm_temp -row 1 -column 1
#grid .frm_temp.lbl_cam -in .frm_temp -row 2 -column 1
#grid .frm_temp.ent_ccd -in .frm_temp -row 1 -column 2
#grid .frm_temp.ent_cam -in .frm_temp -row 2 -column 2

grid .frm_levl.lbl -in .frm_levl -row 1 -column 1
grid .frm_levl.lst -in .frm_levl -row 1 -column 2

grid .frm_ctype.lbl -in .frm_ctype -row 1 -column 1
grid .frm_ctype.lst -in .frm_ctype -row 1 -column 2

grid .frm_eng.lbl -in .frm_eng -row 1 -column 1
grid .frm_eng.ent -in .frm_eng -row 1 -column 2

grid .frm_pos.lbl_theta -in .frm_pos -row 1 -column 1
grid .frm_pos.lbl_phi -in .frm_pos -row 2 -column 1
grid .frm_pos.lbl_rotate -in .frm_pos -row 3 -column 1
grid .frm_pos.ent_theta -in .frm_pos -row 1 -column 2
grid .frm_pos.ent_phi -in .frm_pos -row 2 -column 2
grid .frm_pos.ent_rotate -in .frm_pos -row 3 -column 2

grid .frm_size.lbl_x -in .frm_size -row 1 -column 1
grid .frm_size.lbl_y -in .frm_size -row 2 -column 1
grid .frm_size.ent_x -in .frm_size -row 1 -column 2
grid .frm_size.ent_y -in .frm_size -row 2 -column 2

grid .frm_but.psf -in .frm_but -row 1 -column 1
grid .frm_but.quit -in .frm_but -row 1 -column 2
grid .frm_but.abort -in .frm_but -row 1 -column 3

pack .frm_instr
pack .frm_ccf
#pack .frm_temp
pack .frm_levl
pack .frm_ctype
pack .frm_eng
pack .frm_pos
pack .frm_size
pack .frm_but
